@@ -2,9 +2,9 @@
 ### ====================================================================
 ###  @UNIX-shell-file{
 ###     author          = "Nelson H. F. Beebe",
-###     version         = "0.03",
-###     date            = "28 September 1994",
-###     time            = "00:44:55 MDT",
+###     version         = "0.06",
+###     date            = "04 December 1994",
+###     time            = "13:00:53 MST",
 ###     filename        = "biborder.sh",
 ###     address         = "Center for Scientific Computing
 ###                        Department of Mathematics
@@ -13,7 +13,7 @@
 ###                        USA",
 ###     telephone       = "+1 801 581 5254",
 ###     FAX             = "+1 801 581 4148",
-###     checksum        = "31609 822 2807 23839",
+###     checksum        = "64732 824 2819 23945",
 ###     email           = "beebe@math.utah.edu (Internet)",
 ###     codetable       = "ISO/ASCII",
 ###     keywords        = "bibliography, ordering, BibTeX",
@@ -253,6 +253,7 @@ BEGIN {
 {				# all other line types match this
 	trim()
 	print
+	next
 }
 
 END {
@@ -545,7 +546,7 @@ function clear_array(array, key)
 	delete array[key]
 }
 
-function collect_braced_item( count,item,s)
+function collect_braced_item( count,item,k,s)
 {
     # Starting with the current contents of $0, collect lines until we
     # reach a zero brace count. To guard against infinite loops in the
@@ -578,7 +579,8 @@ function collect_braced_item( count,item,s)
 	# NB: in match() below, \047 is an apostrophe, which we cannot
 	# use inside the sh apostrophe-delimited string containing
 	# this program.
-	if (match($0,/^[ \t]*[A-Za-z][---A-Za-z0-9:.+/\047]*[ \t]*=/))
+	# NB: Add underscore, even though it is not in grammar.
+	if (match($0,/^[ \t]*[A-Za-z][---A-Za-z0-9_:.+\/\047]*[ \t]*=/))
 	    s = collect_key_value_pair()
 	else
 	    s = $0
@@ -642,7 +644,7 @@ function collect_key_value_pair( key,s)
 {
     # This function is called when a line of the form " key = ..." is met.
     s = $0
-    match($0,/[A-Za-z0-9_]+/)
+    match($0,/[A-Za-z][---A-Za-z0-9_:.+\/\047]*/)
     key = substr($0,RSTART,RLENGTH)
     if (key in key_value_pair)
     {
@@ -650,7 +652,7 @@ function collect_key_value_pair( key,s)
 	while (key in key_value_pair)	# append -z to get a unique sort key
 	    key = key "-z"
     }
-    if (match($0,/^[ \t]*[A-Za-z0-9_]+[ \t]*=[ \t]*\"/))
+    if (match($0,/^[ \t]*[A-Za-z][---A-Za-z0-9_:.+\/\047]*[ \t]*=[ \t]*\"/))
     {				# then we have key = "...value..."
 	# Collect any multiline key/value assignment, using the simple
 	# heuristic (guaranteeable by bibclean) that a quoted value string
